@@ -41,39 +41,38 @@ format.rd_section_examples <- function(x, ...) {
 #'
 #' This documentation topic is used primarily for testing and to record
 #' our understanding of the `\example{}` escaping rules.
+#' See <https://developer.r-project.org/parseRd.pdf> for the details provided
+#' by R core.
 #'
 #' @keywords internal
 #' @examples
-#' # The only thing that must be escaped in examples is Rd comments:
+#' # In examples we automatically escape Rd comments (%):
 #' 100 %% 30
 #' # even if they are in strings
 #' "50%"
 #'
-#' # Otherwise, backslashes and braces can be left as is
+#' # and \\ and \v inside of strings and symbols
+#' "\v" # vertical tab
+#' "\\"
+#' # but not comments: \l \v
+#'
+#' # other string escapes are left as is
 #' "\""
-#' "{"
-#' # It looks like you could use Rd tags in comments, but these are
-#' # not actually parsed
-#' 1 # \link{mean}
+#' "\n"
 #'
-#' # The only place that a backslash can occur in R code is as part of
-#' # an infix operator or in a non-syntactic name. If you do either of those
-#' # things, you'll need to escape it yourself.
-#' `%\\\\%` <- function(x, y) x + y
-#' 10 %\\% 20
-#'
-#' # You must escape braces if they are unbalanced, which typically
-#' # only occurs in \dontshow{}:
+#' # Otherwise, backslashes and parentheses are left as is. This
+#' # means that you need to escape unbalanced parentheses, which typically only
+#' # occur in \dontshow{}:
 #' \dontshow{if (FALSE) \{ }
 #' print("Hello")
 #' \dontshow{ \} }
 #'
-#' # Otherwise, you _can_ escape them, but there's little point.
-#' # The following two lines are equivalent
-#' f <- function() { NULL }
-#' f <- function() \{ NULL \}
+#' # You also need to escape backslashes in infix operators and comments
+#' # (this is generally rare)
+#' `%\\%` <- function(x, y) x + y
+#' 10 %\\% 20
+#' # \\\\ (renders as two backslashes)
 escape_examples <- function(x) {
   x <- paste0(x, collapse = "\n")
-  x <- gsub("%", "\\%", x, fixed = TRUE, useBytes = TRUE)
-  rd(x)
+  rd(escapeExamples(x))
 }
